@@ -14,6 +14,7 @@ __all__ = [
     "Component",
     "System",
     "Horizon",
+    "Procedure",
     "Project",
     "ScheduleItem",
     "Schedule",
@@ -348,3 +349,29 @@ class Schedule:
 
         schedules = [p.get_schedule() for p in projects]
         return cls(items=[i for s in schedules for i in s.items])
+
+
+@serde
+@dataclass
+class Procedure:
+    """A specific grouping of tasks to apply to a System.
+
+    Note:
+        Mainly used for plotting purposes.
+
+    Arguments:
+        name: Name for this procedure.
+        system: System (name) to which the procedure should be applied.
+        kind: Kind of procedure (category name).
+        time: Time at which the procedure is scheduled.
+        cost: Cost of the procedure.
+        duration: Duration of the procedure.
+    """
+
+    name: Optional[str] = field(default=None, skip_if_default=True)
+    system: str = "system"
+    kind: str = "procedure"
+    time: Union[int, float] = 1.0
+    cost: Union[int, float] = 1.0
+    duration: Union[int, float] = 1.0
+    uuid: UUID = field(default_factory=uuid4)
